@@ -9,5 +9,7 @@ from docx2python.main import docx2python
 
 def test_dop_1013a() -> None:
     """Misidentifies ``word/document.xml`` as ``word/word/document.xml``"""
-    docx2python("resources/example.docx")
-    docx2python("resources/240-DOP-1013A Lay Down Tubulars.docx")
+    with docx2python("resources/example.docx") as _:
+        pass
+    with docx2python("resources/240-DOP-1013A Lay Down Tubulars.docx") as _:
+        pass
