@@ -1,8 +1,7 @@
 """Test that Word's tilted quotes and double quotes extract Docx2Python."""
 
 from docx2python.main import docx2python
-
-from .conftest import RESOURCES
+from tests.conftest import RESOURCES
 
 
 class TestTiltedQuotes:
